============
Who Uses it?
============

This is a non exhaustive list where MSS is integrated or has inspired.
Do not hesitate to `say Hello! <https://github.com/BoboTiG/python-mss/issues>`_ if you are using MSS too.

- `Airtest <https://github.com/AirtestProject/Airtest>`_, a cross-platform UI automation framework for aames and apps;
- `Automation Framework <https://github.com/capaximperii/AutomationFramework>`_, a Batmans utility;
- `DeepEye <https://github.com/thayerAlshaabi/DeepEye>`_, a deep vision-based software library for autonomous and advanced driver-assistance systems;
- `DoomPy <https://github.com/WNoxchi/DoomPy>`_ (Autonomous Anti-Demonic Combat Algorithms);
- `Europilot <https://github.com/jsistla/eu-pilot>`_, a self-driving algorithm using Euro Truck Simulator (ETS2);
- `Flexx Python UI toolkit <https://github.com/zoofio/flexx>`_;
- `Go Review Partner <https://github.com/pnprog/goreviewpartner>`_, a tool to help analyse and review your game of go (weiqi, baduk) using strong bots;
- `Gradient Sampler <https://github.com/FrankFirsching/gradient_sampler>`_,  sample blender gradients from anything on the screen;
- `gym-mupen64plus <https://github.com/bzier/gym-mupen64plus>`_, an OpenAI Gym environment wrapper for the Mupen64Plus N64 emulator;
- `NativeShot <https://addons.mozilla.org/en-US/firefox/addon/nativeshot/>`_ (Mozilla Firefox module);
- `NCTU Scratch and Python, 2017 Spring <https://github.com/mzshieh/snp2017spring>`_ (Python course);
- `normcap <https://github.com/dynobo/normcap>`_, OCR powered screen-capture tool to capture information instead of images;
- `Open Source Self Driving Car Initiative <https://github.com/OSSDC/OSSDC-VisionBasedACC>`_;
- `OSRS Bot COLOR (OSBC) <https://github.com/kelltom/OSRS-Bot-COLOR>`_, a lightweight desktop client for controlling and monitoring color-based automation scripts (bots) for OSRS and private server alternatives;
- `Philips Hue Lights Ambiance <https://github.com/digital-concrete-jungle/hue-ambiance>`_;
- `Pombo <https://github.com/BoboTiG/pombo>`_, a thief recovery software;
- `Python-ImageSearch <https://github.com/drov0/python-imagesearch>`_, a wrapper around OpenCV2 and PyAutoGUI to do image searching easily;
- `PUBGIS <https://github.com/andrewzwicky/PUBGIS>`_, a map generator of your position throughout PUBG gameplay;
- `ScreenCapLibrary <https://github.com/mihaiparvu/ScreenCapLibrary>`_, a Robot Framework test library for capturing screenshots and video recording;
- `ScreenVivid <https://www.screenvivid.com/>`_,  an open source cross-platform screen recorder for everyone ;
- `Self-Driving-Car-3D-Simulator-With-CNN <https://github.com/sagar448/Self-Driving-Car-3D-Simulator-With-CNN>`_;
- `Serpent.AI <https://github.com/SerpentAI/SerpentAI>`_, a Game Agent Framework;
- `Star Wars - The Old Republic: Galactic StarFighter <https://github.com/RedFantom/gsf-parser>`_ parser;
- `Stitch <https://nathanlopez.github.io/Stitch/>`_, a Python Remote Administration Tool (RAT);
- `TensorKart <https://github.com/kevinhughes27/TensorKart>`_, a self-driving MarioKart with TensorFlow;
- `videostream_censor <https://github.com/SergeyKalutsky/vsc>`_, a real time video recording censor ;
- `wow-fishing-bot <https://github.com/rsamf/wow-fishing-bot>`_, a fishing bot for World of Warcraft that uses template matching from OpenCV;
- `Zelda Bowling AI <https://github.com/Velidir/ZeldaBowlingAI>`_;
